==> activity-center-api-3.5.73-sources.jar: cn/com/duiba/activity/center/api/dto/haggle/HaggleConfigDto.java <==
package cn.com.duiba.activity.center.api.dto.haggle;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author: lufeng
 * @Description: 砍价活动配置dto
 * @Date: Created in 2019/9/23
 */
public class HaggleConfigDto implements Serializable{

    private static final long serialVersionUID = 2992056488578852399L;

    private Long id;

    //是否是发布
    private boolean isPublish;

    //入库id
    private Long opId;

    //应用id
    private Long appId;

    //投放渠道。1:app，2:微信公众号
    private Integer channel;

    //标题
    private String title;

    //规则
    private String rule;

    //开始时间
    private Date startTime;

    //结束时间
    private Date endTime;

    //入口缩略图
    private String smallImage;

    //banner图
    private String bannerImage;

    //虚拟弹幕开关。1:开，2:关
    private Integer barrageSwitch;

    //帮砍用户类型。1:仅新用户，2:不限用户
    private Integer helpUserType;

    //帮砍次数上限。1:不限制，2:限制
    private Integer helpLimit;

    //帮砍次数
    private Integer helpLimitCount;

    //发起砍价上限。1:不限制，2:限制
    private Integer openLimit;

    //发起砍价次数
    private Integer openLimitCount;

    /**
     * 新老用户汇率
     */
    private Integer newUserRate;

    //界面配置
    private String interfaceConfig;

    //二维码
    private String qrCode;

    //分享图标
    private String shareIcon;

    //分享标题
    private String shareTitle;

    //分享副标题
    private String shareViceTitle;

    //app分享的回调地址
    private String callbackUrl;

    //微信公众号自动回复
    private String autoReply;

    private String extra;

    /**
     * 资源位图片--雅迪定制字段
     */
    private String resourceBitImage;

    /**
     * 资源位跳转链接--雅迪定制字段
     */
    private String resourceBitUrl;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getOpId() {
        return opId;
    }

    public void setOpId(Long opId) {
        this.opId = opId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getChannel() {
        return channel;
    }

    public void setChannel(Integer channel) {
        this.channel = channel;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public Integer getBarrageSwitch() {
        return barrageSwitch;
    }

    public void setBarrageSwitch(Integer barrageSwitch) {
        this.barrageSwitch = barrageSwitch;
    }

    public Integer getHelpUserType() {
        return helpUserType;
    }

    public void setHelpUserType(Integer helpUserType) {
        this.helpUserType = helpUserType;
    }

    public Integer getHelpLimit() {
        return helpLimit;
    }

    public void setHelpLimit(Integer helpLimit) {
        this.helpLimit = helpLimit;
    }

    public Integer getHelpLimitCount() {
        return helpLimitCount;
    }

    public void setHelpLimitCount(Integer helpLimitCount) {
        this.helpLimitCount = helpLimitCount;
    }

    public Integer getOpenLimit() {
        return openLimit;
    }

    public void setOpenLimit(Integer openLimit) {
        this.openLimit = openLimit;
    }

    public Integer getOpenLimitCount() {
        return openLimitCount;
    }

    public void setOpenLimitCount(Integer openLimitCount) {
        this.openLimitCount = openLimitCount;
    }

    public Integer getNewUserRate() {
        return newUserRate;
    }

    public void setNewUserRate(Integer newUserRate) {
        this.newUserRate = newUserRate;
    }

    public String getInterfaceConfig() {
        return interfaceConfig;
    }

    public void setInterfaceConfig(String interfaceConfig) {
        this.interfaceConfig = interfaceConfig;
    }

    public String getQrCode() {
        return qrCode;
    }

    public void setQrCode(String qrCode) {
        this.qrCode = qrCode;
    }

    public String getShareIcon() {
        return shareIcon;
    }

    public void setShareIcon(String shareIcon) {
        this.shareIcon = shareIcon;
    }

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareViceTitle() {
        return shareViceTitle;
    }

    public void setShareViceTitle(String shareViceTitle) {
        this.shareViceTitle = shareViceTitle;
    }

    public String getCallbackUrl() {
        return callbackUrl;
    }

    public void setCallbackUrl(String callbackUrl) {
        this.callbackUrl = callbackUrl;
    }

    public String getAutoReply() {
        return autoReply;
    }

    public void setAutoReply(String autoReply) {
        this.autoReply = autoReply;
    }

    public boolean isPublish() {
        return isPublish;
    }

    public void setPublish(boolean publish) {
        isPublish = publish;
    }

    public String getResourceBitImage() {
        return resourceBitImage;
    }

    public void setResourceBitImage(String resourceBitImage) {
        this.resourceBitImage = resourceBitImage;
    }

    public String getResourceBitUrl() {
        return resourceBitUrl;
    }

    public void setResourceBitUrl(String resourceBitUrl) {
        this.resourceBitUrl = resourceBitUrl;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }
}

==> activity-center-api-3.6.11-20250109.122334-10-sources.jar: cn/com/duiba/activity/center/api/dto/haggle/HaggleConfigDto.java <==
package cn.com.duiba.activity.center.api.dto.haggle;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author: lufeng
 * @Description: 砍价活动配置dto
 * @Date: Created in 2019/9/23
 */
public class HaggleConfigDto implements Serializable{

    private static final long serialVersionUID = 2992056488578852399L;

    private Long id;

    //是否是发布
    private boolean isPublish;

    //入库id
    private Long opId;

    //应用id
    private Long appId;

    //投放渠道。1:app，2:微信公众号
    private Integer channel;

    //标题
    private String title;

    //规则
    private String rule;

    //开始时间
    private Date startTime;

    //结束时间
    private Date endTime;

    //入口缩略图
    private String smallImage;

    //banner图
    private String bannerImage;

    //虚拟弹幕开关。1:开，2:关
    private Integer barrageSwitch;

    //帮砍用户类型。1:仅新用户，2:不限用户
    private Integer helpUserType;

    //帮砍次数上限。1:不限制，2:限制
    private Integer helpLimit;

    //帮砍次数
    private Integer helpLimitCount;

    //发起砍价上限。1:不限制，2:限制
    private Integer openLimit;

    //发起砍价次数
    private Integer openLimitCount;

    /**
     * 新老用户汇率
     */
    private Integer newUserRate;

    //界面配置
    private String interfaceConfig;

    //二维码
    private String qrCode;

    //分享图标
    private String shareIcon;

    //分享标题
    private String shareTitle;

    //分享副标题
    private String shareViceTitle;

    //app分享的回调地址
    private String callbackUrl;

    //微信公众号自动回复
    private String autoReply;

    private String extra;

    /**
     * 资源位图片--雅迪定制字段
     */
    private String resourceBitImage;

    /**
     * 资源位跳转链接--雅迪定制字段
     */
    private String resourceBitUrl;
    /**
     * 广汽定制：是否限制仅限车主参与
     * false 不限制 true 限制
     */
    private Boolean gqJoinLimit;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getOpId() {
        return opId;
    }

    public void setOpId(Long opId) {
        this.opId = opId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getChannel() {
        return channel;
    }

    public void setChannel(Integer channel) {
        this.channel = channel;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public Integer getBarrageSwitch() {
        return barrageSwitch;
    }

    public void setBarrageSwitch(Integer barrageSwitch) {
        this.barrageSwitch = barrageSwitch;
    }

    public Integer getHelpUserType() {
        return helpUserType;
    }

    public void setHelpUserType(Integer helpUserType) {
        this.helpUserType = helpUserType;
    }

    public Integer getHelpLimit() {
        return helpLimit;
    }

    public void setHelpLimit(Integer helpLimit) {
        this.helpLimit = helpLimit;
    }

    public Integer getHelpLimitCount() {
        return helpLimitCount;
    }

    public void setHelpLimitCount(Integer helpLimitCount) {
        this.helpLimitCount = helpLimitCount;
    }

    public Integer getOpenLimit() {
        return openLimit;
    }

    public void setOpenLimit(Integer openLimit) {
        this.openLimit = openLimit;
    }

    public Integer getOpenLimitCount() {
        return openLimitCount;
    }

    public void setOpenLimitCount(Integer openLimitCount) {
        this.openLimitCount = openLimitCount;
    }

    public Integer getNewUserRate() {
        return newUserRate;
    }

    public void setNewUserRate(Integer newUserRate) {
        this.newUserRate = newUserRate;
    }

    public String getInterfaceConfig() {
        return interfaceConfig;
    }

    public void setInterfaceConfig(String interfaceConfig) {
        this.interfaceConfig = interfaceConfig;
    }

    public String getQrCode() {
        return qrCode;
    }

    public void setQrCode(String qrCode) {
        this.qrCode = qrCode;
    }

    public String getShareIcon() {
        return shareIcon;
    }

    public void setShareIcon(String shareIcon) {
        this.shareIcon = shareIcon;
    }

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareViceTitle() {
        return shareViceTitle;
    }

    public void setShareViceTitle(String shareViceTitle) {
        this.shareViceTitle = shareViceTitle;
    }

    public String getCallbackUrl() {
        return callbackUrl;
    }

    public void setCallbackUrl(String callbackUrl) {
        this.callbackUrl = callbackUrl;
    }

    public String getAutoReply() {
        return autoReply;
    }

    public void setAutoReply(String autoReply) {
        this.autoReply = autoReply;
    }

    public boolean isPublish() {
        return isPublish;
    }

    public void setPublish(boolean publish) {
        isPublish = publish;
    }

    public String getResourceBitImage() {
        return resourceBitImage;
    }

    public void setResourceBitImage(String resourceBitImage) {
        this.resourceBitImage = resourceBitImage;
    }

    public String getResourceBitUrl() {
        return resourceBitUrl;
    }

    public void setResourceBitUrl(String resourceBitUrl) {
        this.resourceBitUrl = resourceBitUrl;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Boolean getGqJoinLimit() {
        return gqJoinLimit;
    }

    public void setGqJoinLimit(Boolean gqJoinLimit) {
        this.gqJoinLimit = gqJoinLimit;
    }
}
